def dodawanie():
    d1 = float(input("Podaj pierwsza liczbe: "))
    d2 = float(input("Podaj druga liczbe: "))
    suma = d1 + d2
    print("Twoj wynik to: ", suma)


def odejmowanie():
    o1 = float(input("Podaj pierwsza liczbe: "))
    o2 = float(input("Podaj druga liczbe: "))
    roznica = o1 - o2
    print("Twoj wynik to: ", roznica)


def mnozenie():
    mm = str(input("Przez ile liczb chcesz mnozyc? [2] lub [3]: "))
    if mm == ("2"):
        m1 = float(input("Podaj pierwsza liczbe: "))
        m2 = float(input("Podaj druga liczbe: "))
        iloczyn = m1 * m2
        print("Twoj wynik to: ", iloczyn)
    if mm == ("3"):
        m1 = float(input("Podaj pierwsza liczbe: "))
        m2 = float(input("Podaj druga liczbe: "))
        m3 = float(input("Podaj trzecia liczbe: "))
        iloczyn = m1 * m2 * m3
        print("Twoj wynik to: ", iloczyn)


def dzielenie():
    dz1 = float(input("Podaj pierwsza liczbe: "))
    dz2 = float(input("Podaj druga liczbe: "))
    iloraz = dz1 / dz2
    print("Twoj wynik to: ", iloraz)


def kalkulator():
    while True:
        x = input("Dodawanie, odejmowanie, mnozenie czy dzielenie? ")
        if x == ("dodawanie"):
            dodawanie()
        if x == ("odejmowanie"):
            odejmowanie()
        if x == ("mnozenie"):
            mnozenie()
        if x == ("dzielenie"):
            dzielenie()

        decyzja = input("Czy chcesz kontynuować? tak/nie ")
        if decyzja == "nie":
            print("Dziękujemy za obliczenia")
            break

if __name__ == "__main__":
    kalkulator()


from setuptools import find_packages, setup
import os


def read_file(filename):
    with open(os.path.join(os.path.dirname(__file__), filename)) as file:
        return file.read()


setup(
    name='kalkulatorxxx',
    version='0.4.0',
    author='Jakub Cichowski',
    author_email='kubaxdd1234@wp.pl',
    packages=find_packages(),
    include_package_data=True,
    description='Simple Calculator',
    long_description=read_file('README.md'),
    long_description_content_type='text/markdown'
)
